
=========================
 API Reference — Almanac
=========================

.. currentmodule:: skyfield.almanac

See :doc:`almanac` for a guide to using these routines to search for the
times of sunrise, sunset, and the phases of the moon.

.. autofunction:: phase_angle

.. autofunction:: fraction_illuminated

.. autofunction:: find_discrete

.. autofunction:: seasons

.. autofunction:: moon_phases

.. autofunction:: moon_nodes

.. autofunction:: oppositions_conjunctions

.. autofunction:: sunrise_sunset

.. autofunction:: dark_twilight_day

.. autofunction:: risings_and_settings
